from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.md') as history_file:
    history = history_file.read()

requirements = [
    'apistar==0.5.40',
    'certifi==2018.4.16',  # via requests
    'chardet==3.0.4',  # via requests
    'click==6.7',  # via apistar
    'idna==2.7',  # via requests
    'jinja2==2.10',  # via apistar
    'markupsafe==1.0',  # via jinja2
    'marshmallow==2.15.3',
    'psycopg2==2.7.5',
    'pyyaml==3.12',  # via apistar
    'requests==2.19.1',  # via apistar
    'sqlalchemy==1.2.9',
    'urllib3==1.23',  # via requests
    'werkzeug==0.14.1',  # via apistar
    'whitenoise==3.3.1',  # via apistar
]

dev_requirements = [
    'atomicwrites==1.1.5',  # via pytest
    'attrs==18.1.0',  # via pytest
    'click==6.7',  # via pip-tools
    'first==2.0.1',  # via pip-tools
    'flake8==3.5.0',
    'mccabe==0.6.1',  # via flake8
    'more-itertools==4.2.0',  # via pytest
    'pip-tools==2.0.2',
    'pluggy==0.6.0',  # via pytest, tox
    'py==1.5.4',  # via pytest, tox
    'pycodestyle==2.3.1',  # via flake8
    'pyflakes==1.6.0',  # via flake8
    'pytest==3.6.2',
    'six==1.11.0',  # via more-itertools, pip-tools, pytest, tox
    'tox==3.0.0',
    'virtualenv==16.0.0',  # via tox
    'wheel==0.31.1',
]

setup(
    name='news',
    version='0.2.1',
    description="A ReSTful api for storing and retrieving news articles",
    long_description=readme + '\n\n' + history,
    long_description_content_type='text/markdown',
    author="Drew Bednar",
    author_email='drew@androiddrew.com',
    url='https://git.aigalactic.com/Spyglass/news',
    packages=find_packages(include=['news', 'scripts']),
    include_package_data=True,
    install_requires=requirements,
    license='MIT',
    keywords='news spyglass',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Backend',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    extras_require={
        'dev': dev_requirements,
    },
    entry_points={
        'console_scripts': [
            'wsgi_serve=scripts.wsgi_app:main'
        ]
    },

)
